| Title: | Calculating Heat Stress |
|---|---|
| Description: | Implements the simpler and faster heat index, which matches the values of the original 1979 heat index and its 2022 extension for air temperatures above 300 K (27 C, 80 F) and with only minor differences at lower temperatures. Also implements an algorithm for calculating the thermodynamic (and psychrometric) wet-bulb (and ice-bulb) temperature. |
| Authors: | Yi-Chuan Lu [aut] (ORCID: <https://orcid.org/0000-0003-3659-1474>), David M. Romps [aut, cre] (ORCID: <https://orcid.org/0000-0001-7649-5175>) |
| Maintainer: | David M. Romps <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.2 |
| Built: | 2026-05-14 07:20:59 UTC |
| Source: | https://github.com/cran/heatindex |
heatindex is a simpler and faster version of the heat index that was originally defined in 1979, used by the U.S. National Weather Service, extended to all combinations of temperature and humidity in 2022, and then made simpler and faster in 2025. This simpler and faster version uses a simpler set of physiological equations and a faster computational algorithm without altering the values of the heat index above 300 K (27 C, 80 F) and with only minor changes in the heat index at lower temperatures.
heatindex(T, rh)heatindex(T, rh)
T |
The absolute air temperature in Kelvin. This can be a single number, a vector, a matrix, or an array, but its dimensions must match those of |
rh |
The relative humidity of the air, with values in the range of 0 to 1, with respect to saturation over liquid water for air temperatures over 273.16 K and with respect to saturation over ice for air temperatures lower than 273.16 K. This can be a single number, a vector, a matrix, or an array, but its dimensions must match those of |
The values of the heat index, in Kelvin, in the same shape as T and rh.
Yi-Chuan Lu [email protected] and David M. Romps [email protected]
Steadman, R. G. (1979). The assessment of sultriness. Part I: A temperature-humidity index based on human physiology and clothing science. Journal of Applied Meteorology, 18, 861-873. doi:10.1175/1520-0450(1979)018<0861:TAOSPI>2.0.CO;2
Lu, X. and Romps, D. M. (2022). Extending the heat index. Journal of Applied Meteorology, 61, 10, 1367–1383. doi:10.1175/jamc-d-22-0021.1
Lu et al. (2025). Simpler and faster: an improved heat index. In review. For citation details, see https://heatindex.org/docs/citation/.
heatindex(300,0.5) heatindex(295:305,0:10/10)heatindex(300,0.5) heatindex(295:305,0:10/10)
rh_from_wetbulb calculates the relative humidity from the thermodynamic (or psychrometric) wet-bulb (or ice-bulb) temperature using the Rankine-Kirchhoff approximations.
rh_from_wetbulb( p, T, Tw, psychrometric = FALSE, icebulb = FALSE, verbose = TRUE, lewis = 0.85 )rh_from_wetbulb( p, T, Tw, psychrometric = FALSE, icebulb = FALSE, verbose = TRUE, lewis = 0.85 )
p |
The total air pressuire in Pa. This can be a single number, a vector, a matrix, or an array. |
T |
The absolute air temperature in Kelvin. This can be a single number, a vector, a matrix, or an array. |
Tw |
The thermodynamic (or psychrometric) wet-bulb (or ice-bulb) temperature in Kelving. This can be a single number, a vector, a matrix, or an array. |
psychrometric |
A logical indicating whether to interpret |
icebulb |
A logical indicating whether to interpret |
verbose |
A logical indicating whether or not to print warning messages. Default is |
lewis |
The Lewis number for moist air. Default is |
Relative humidity in the same shape as p, T, and Tw. The relative humidity is reported with respect to liquid water if T is greater than or equal to 273.16 K and with respect to ice if T is less than 273.16 K.
David M. Romps [email protected]
Romps, D. M. (2025). Wet-bulb temperature from pressure, relative humidity, and air temperature. In review.
rh_from_wetbulb(1e5,300,290) rh_from_wetbulb(1e5,301:310,290) rh_from_wetbulb(1e5,301:310,291:300) rh_from_wetbulb(1:10*1e4,301:310,291:300)rh_from_wetbulb(1e5,300,290) rh_from_wetbulb(1e5,301:310,290) rh_from_wetbulb(1e5,301:310,291:300) rh_from_wetbulb(1:10*1e4,301:310,291:300)
wetbulb calculates the thermodynamic (or psychrometric) wet-bulb (or ice-bulb) temperature using the Rankine-Kirchhoff approximations.
wetbulb( p, T, rh, psychrometric = FALSE, icebulb = FALSE, verbose = TRUE, lewis = 0.85 )wetbulb( p, T, rh, psychrometric = FALSE, icebulb = FALSE, verbose = TRUE, lewis = 0.85 )
p |
The total air pressuire in Pa. This can be a single number, a vector, a matrix, or an array. |
T |
The absolute air temperature in Kelvin. This can be a single number, a vector, a matrix, or an array. |
rh |
The relative humidity of the air, with values in the range of 0 to 1, with respect to saturation over liquid water for air temperatures over 273.16 K and with respect to saturation over ice for air temperatures lower than 273.16 K. This can be a single number, a vector, a matrix, or an array. |
psychrometric |
A logical indicating whether to calculate the thermodynamic wet-bulb temperature (if |
icebulb |
A logical indicating whether to calculate the temperature of an ice-bulb (if |
verbose |
A logical indicating whether or not to print warning messages. Default is |
lewis |
The Lewis number for moist air. Default is |
The values of the wet-bulb temperature, in Kelvin, in the same shape as p, T, and rh.
David M. Romps [email protected]
Romps, D. M. (2025). Wet-bulb temperature from pressure, relative humidity, and air temperature. In review.
wetbulb(1e5,300,0) wetbulb(1e5,301:310,0) wetbulb(1e5,301:310,1:10/10) wetbulb(1:10*1e4,301:310,1:10/10)wetbulb(1e5,300,0) wetbulb(1e5,301:310,0) wetbulb(1e5,301:310,1:10/10) wetbulb(1:10*1e4,301:310,1:10/10)